/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.logging.ri.log4j;

import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;
import org.jdtaus.core.container.PropertyException;
import org.jdtaus.core.logging.spi.Logger;

/**
 * jDTAUS Core SPI Log4J {@code Logger} implementation.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: Log4JLogger.java 4077 2007-07-29 21:48:34Z schulte2005 $
 *
 * @see org.jdtaus.core.container.Container
 * @see #initialize()
 */
public final class Log4JLogger implements ContainerInitializer, Logger
{
    //--Implementation----------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausImplementation
    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(Log4JLogger.class.getName());
// </editor-fold>//GEN-END:jdtausImplementation

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausConstructors
    // This section is managed by jdtaus-container-mojo.

    /**
     * <code>Log4JLogger</code> implementation constructor.
     *
     * @param meta Implementation meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    private Log4JLogger(final Implementation meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }
    /**
     * <code>Log4JLogger</code> dependency constructor.
     *
     * @param meta dependency meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    private Log4JLogger(final Dependency meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    private void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

        p = meta.getProperty("name");
        this._name = (java.lang.String) p.getValue();

    }
// </editor-fold>//GEN-END:jdtausConstructors

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Log4J logger. */
    private org.apache.log4j.Logger logger;

    /**
     * Requests a Log4J logger for the name given by property {@code name}.
     *
     * @see #assertValidProperties()
     */
    public void initialize()
    {
        this.assertValidProperties();
        this.logger = org.apache.log4j.Logger.getLogger(this.getName());
    }

    //----------------------------------------------------ContainerInitializer--
    //--Properties--------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausProperties
    // This section is managed by jdtaus-container-mojo.

    /**
     * Property {@code name}.
     * @serial
     */
    private java.lang.String _name;

    /**
     * Gets the value of property <code>name</code>.
     *
     * @return the value of property <code>name</code>.
     */
    private java.lang.String getName()
    {
        return this._name;
    }

// </editor-fold>//GEN-END:jdtausProperties

    //--------------------------------------------------------------Properties--
    //--Logger------------------------------------------------------------------

    public boolean isDebugEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.DEBUG);
    }

    public void debug(String string)
    {
        this.logger.debug(string);
    }

    public void debug(Throwable throwable)
    {
        this.logger.debug(throwable.getMessage(), throwable);
    }

    public boolean isErrorEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.ERROR);
    }

    public void error(String string)
    {
        this.logger.error(string);
    }

    public void error(Throwable throwable)
    {
        this.logger.error(throwable.getMessage(), throwable);
    }

    public boolean isFatalEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.FATAL);
    }

    public void fatal(String string)
    {
        this.logger.fatal(string);
    }

    public void fatal(Throwable throwable)
    {
        this.logger.fatal(throwable.getMessage(), throwable);
    }

    public boolean isInfoEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.INFO);
    }

    public void info(String string)
    {
        this.logger.info(string);
    }

    public void info(Throwable throwable)
    {
        this.logger.info(throwable.getMessage(), throwable);
    }

    public boolean isTraceEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.TRACE);
    }

    public void trace(String string)
    {
        this.logger.trace(string);
    }

    public void trace(Throwable throwable)
    {
        this.logger.trace(throwable.getMessage(), throwable);
    }

    public boolean isWarnEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.WARN);
    }

    public void warn(String string)
    {
        this.logger.warn(string);
    }

    public void warn(Throwable throwable)
    {
        this.logger.warn(throwable.getMessage(), throwable);
    }

    //------------------------------------------------------------------Logger--
    //--Log4JLogger-------------------------------------------------------------

    /** Creates a new {@code Log4JLogger} instance. */
    public Log4JLogger()
    {
        this(Log4JLogger.META);
        this.initialize();
    }

    /**
     * Checks configured properties.
     *
     * @throws PropertyException if property {@code name} is {@code null} or
     * of no length.
     */
    private void assertValidProperties()
    {
        if(this.getName() == null || this.getName().length() <= 0)
        {
            throw new PropertyException("name", this.getName());
        }
    }

    //-------------------------------------------------------------Log4JLogger--
}
